.; Last update:  10/21/92  05:04 PM  (Edition: 3)
.TH TARMAIL 1 local
.SH NAME
tarmail, untarmail \- reliable send/receive files through mail system
.br
btoa, atob \- encode/decode binary to printable ASCII
.SH SYNOPSIS
.B tarmail
[-b block_size] [-p part_number] [-c] [-t] [-s n] [-T hh:mm]
who subject files ...
.br
.RS 8
.TP 16
-b \fIblock_size\fR
set each block to \fIblock_size\fR bytes, default 20000
.TP 16
-p \fIn\fR
send only part \fIn\fR, e.g., -p 10, -p 10,15, -p 3-7, -p 3,7,11-14
.TP 16
-c
dont run thru compress, use for already compressed files, e.g., epoch.tar.Z
.TP 16
-t
trickle mode
.TP 16
-s \fIsec\fR
sleep \fIsec\fR seconds between trickles
.TP 16
-T \fIhh:mm\fR
set trickle starting time to be \fIhh:mm\fR
.RE
.br
.B untarmail
[-k] [-t dir] [ files ... ]
.RS 8
.TP 16
-k
keep the original files instead of moving them to /usr/tmp
.RE
.RS 8
.TP 16
-t \fIdir\fR
use \fIdir\fR as the temporary directory instead of the default /tmp
.RE
.B btoa
.br
.B atob
.br
.SH DESCRIPTION
The tarmail package is composed of 5 programs: \fItarmail\fR,
\fIuntarmail\fR are the top layer programs for sending/receiving
packages; \fIbtoa\fR, \fIatob\fR, and \fIchunk\fR are filters used by
tarmail and untarmail.  \fIChunk\fR is documented in a separated man
page.  The following sections describe each program in detail.
.SH FILTERS btoa and atob
.I Btoa
is a filter that reads anything from the standard input, and encodes
it into printable ASCII on the standard output.  It also attaches a
header and checksum information used by the reverse filter
.I atob 
to find the start of the data and to check integrity.
.PP
.I Atob
reads an encoded file, strips off any leading and trailing lines added
by mailers, and recreates a copy of the original file on the standard
output.
.I Atob 
gives NO output (and exits with an error message) if its input is
garbage or the checksums do not check.
.SH TARMAIL
.I Tarmail
is a shell script that tar's up all the given files, pipes them
through
.IR compress ","
.IR btoa ","
and mails them to the given person with the given subject phrase.  For
example:
.PP
.in 1i
tarmail ralph "here it is ralph" foo.c a.out
.in -1i
.PP
Will package up files "foo.c" and "a.out" and mail them to "ralph"
using subject "here it is ralph".  Notice the quotes on the subject.
They are necessary to make it one argument to the shell.
.PP
Tarmail will pack the mail in
.I smaller chunks
if the mail is too big.  The default chunk size is 20000 bytes before
running btoa, and will be some percentage bigger than that.  String
like: "(part 1/5)" will be appended at the end of the subject. This
string is the sole clue for untarmail to put them back in the proper
order.
.PP
Each mail will be filtered by btoa with CRC checksum, this allows
individual package be retransmitted.  The sender will have to repeat
the original tarmail command with additional -p option to send out
only the parts that are corrupted.  The part numbers can be specified
in (1) number, (2) range like m-n, or (3) list of comma separated
numbers or ranges
.PP
Trickle mode is specified by -t flag which will create a sh script in
caller's home directory and queue it for transmission when
communication cost is the lowest.  Trickle mode should be used when
sending large packages.  The default starting time for trickle mode is
11 pm when the phone rate drops, it may be overrided by -T options.
The default interval between each trickle is one day which may be
overrided by -s option.  Take precaution if you are going to override
the trickle interval so it will not send out packages during regular
phone rate hours.
.PP
.I Tarmail 
with no args will print a short message reminding you what the
required args are.
.SH UNTARMAIL
When the mail is received at the other end, that person should use
mail to save the message in some temporary file name (say "xx").  Then
saying "untarmail xx" will decode the message and untar it.
.PP
If you receive a tarmail with multiple mails, you should save each of
them in a separate file and then feed them to untarmail, e.g.,
.nf
	$ untarmail perl5 perl2 perl3 perl4 perl1
.fi
.PP
Untarmail will sort them in proper order.  If there is any part missed,
untarmail will reject the request.
.PP
.I Untarmail 
can also be used as a filter.  By using 
.IR tarmail ","
binary files and
entire directory structures can be easily transmitted between machines.
Naturally, you should understand what tar itself does before you use 
.IR tarmail "."
.SH EXAMPLES:
.IP "    \(bu"
The following command will send all the files under /usr/man/manl to
jms@x11.nt.com
.nf
	$ tarmail jms@x11.nt.com 'local manuals' /usr/man/manl
.fi
.IP "    \(bu"
The following command will send ghostview-1.4.tar.Z to lew@gsg.com,
the -c option is used so the file will not be compressed agin:
.nf
	$ tarmail -c lew@gsg.com ghostview-1.4.tar.Z
.fi
.IP "    \(bu"
The following command will send epoch.tar.Z to lew@gsg.com in trickle
mode:
.nf
	$ tarmail -t -c lew@gsg.com epoch.tar.Z epoch.tar.Z
.fi
.IP "    \(bu"
The following command will send part 3 and part 7 of epoch.tar.Z to
lew@gsg.com:
.nf
	$ tarmail -p 3,7 -c lew@gsg.com epoch.tar.Z epoch.tar.Z
.fi
.SH OTHER USES:
.PP
compress < secrets | crypt | btoa | mail ralph
.PP
will mail the encrypted contents of the file "secrets" to ralph.  If ralph
knows the encryption key, he can decode it by saving the mail (say in "xx"),
and then running:
.PP
atob < xx | crypt | uncompress
.PP
(crypt requests the key from the terminal,
and the "secrets" come out on the terminal).
.SH VERSION
.nf
tarmail		Version 2.3
untarmail	Version 2.3
atob		Version ??
btoa		Version 4.0
.fi
.SH AUTHOR
Paul Rutter, original author
.br
Paul Lew, modified since version 2.0
.SH FEATURES
.I Btoa
uses a compact base-85 encoding so that 4 bytes are encoded into 5
characters (file is expanded by 25%).  As a special case, 32-bit zero
is encoded as one character.  This encoding produces less output than
.IR uuencode "(1)."
.SH BUGS
Untarmail will search for string: "(part " in the subject line to
identify individual parts.  Subject with "(part " in it will be
processed.  This might cause problem when untarmail a package
generated from previous version of tarmail.
.PP
Pay extra attention to flag -\fIc\fR when resend any corrupted parts.
It will not work properly if the original tarmail specifies -\fIc\fR
option while the resend does not.
.SH "SEE ALSO"
compress(1), crypt(1), uuencode(1), mail(1)
.;
.;;; Local Variables:			***
.;;; mode: nroff			***
.;;; ispell-filter-hook: "deroff"	***
.;;; ispell-filter-hook-args: ("-w")	***
.;;; End:				***
